@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 16.04.0 - http://gufw.org
+# Gufw 16.04.1 - http://gufw.org
 # Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -16,6 +16,9 @@
 # along with Gufw; if not, see http://www.gnu.org/licenses for more
 # information.
 
+import gi
+gi.require_version('Gtk', '3.0')
+gi.require_version('WebKit', '3.0')
 from gi.repository import Gtk, Gdk, WebKit
 from string import Template
 
